function tip
%  Tip.m call program: simply type tip at the Matlab prompt
%  It takes rain gauge data from a file or files and computes the tips/min,
%  and then uses the calibration data for the gauges to appropriately
%  weight the data. It then writes the data to a specified output text
%  file, which can then be opened in Excel. 
%  
%     (To format the Excel cells, you
%  can select "Format cells - custom" and enter mm/dd/yyyy hh:mm:ss or
%  whatever you choose in order to make your plot. When initially writing
%  the cells to Excel, we kept only the boundary line between the depth per
%  tip guess and erased the one between date & time.)
%
%  Input (all inputs occur during program execution):
%   g = number of the gauge the data is coming from (integer)
%   numfile = the number of files that will be read  (integer)
%   infile = the filename(s) that will be read by the program (character
%       string)
%   outputfile = the (1) file the program writes to
%
%   Output
%    cumulativeinches = the total amount of rain, in inches, reported by
%    the gauge
%
%   Other Variables
%       dmm=depth per tip in mm (from calibration)
%       tipmin=tips per minute (from calibration)
%       k,i=variables for the loop counters
%       fid=variable to tell the fprintf command where to write its
%           information
%       date=cell array containing the dates as strings
%       datenew=a matrix which contains the dates as integers
%       year=vector containing the years
%       month=vector containing the months
%       day=vector containing the days
%       sec=vector containing the time in decimal form that can be
%           manipulated mathematically
%       timetip=vector containing the time between each tip in seconds
%       timetipmin=vector containing the time between each tip in minutes
%       monthd=a vector of length 12 containing the number of days in each
%           month
%       wt1-wt4= different weights for each tip, depending on rainfall type
%       dtg=depth per tip guess for each tip, based on weights and
%           calibration dmm
%       y=vector of the information the fprintf command will write to a
%           file
%
%   Additional Function Called: timefunc - tells the program how many days
%   are in each month, depending on whether or not it is a leap year.

g=input('What gauge are you using? ');
if g==2
    dmm=[.207 .213 .2109 .211];
    tipmin=[4.640 7.953 14.913 19.768];
elseif g==1
    dmm=[.192 .192 .193 .193];
    tipmin=[4.955 8.919 16.5 21.479];
elseif g==3
    dmm=[.2 .203 .203 .2015];
    tipmin=[4.668 8.464 15.430 21.037];
elseif g==4
    dmm=[.199 .199 .197 .19951];
    tipmin=[4.785 9.012 15.511 20.408];
elseif g==5
    dmm=[.193 .196 .198 .1968];
    tipmin=[4.761 8.641 15.812 20.447];
elseif g==8
    dmm=[.198 .198 .202 .201];
    tipmin=[4.808 9.208 15.665 20.668];
elseif g==10
    dmm=[.199 .197 .198 .20096];
    tipmin=[4.853 9.190 16.108 20.465];
else
    error('We do not have data for that gauge at this time.'),quit
end

%keep as many significant digits as possible
format long

numfile=input('How many files would you like to convert? ');
outputfile=input('Please enter the text file where you would like the data to go, in this format, with single quotes: ''filename.txt'': ');
fid=fopen(outputfile,'wt');

%begin loop to last for the number of files the user wants to enter
for k=1:numfile
    infile=input('Enter the filename in the same format as before: ');
    
    %read the text file of rain gauge data - read the date as a string, the
    %hours & minutes as integers, the seconds as decimals, and the tips as
    %integers.
    %make sure to skip the header line (each file has a line stating
    %'Date/Time    Event')

    [date, h,m,s, event]=textread(infile,'%8s %d %d %f %d','delimiter',':','headerlines',1);

    %convert the date string into numeric data, using 2000 as the pivot year
    datenew=datevec(date,2000);

    %separate the new date vector into year month and day
    year = datenew(:,1);
    month = datenew(:,2);
    day = datenew(:,3);

    %turn the hours, minutes and seconds into one decimal number that can be
    %added and subtracted.
    sec=hms2sec(h,m,s);

    %find the time between tips for each tip and put them into a vector
    for i = 1:(length(year)-1)
        if ((year(i)==year(i+1))&&(month(i)==month(i+1))&&(day(i)==day(i+1)))
            timetip(i)=sec(i+1)-sec(i);
        elseif ((year(i)==year(i+1))&&(month(i)==month(i+1))&&(day(i)~=day(i+1)))
            timetip(i)=(sec(i+1)-sec(i))+((day(i+1)-day(i))*86400);
        elseif (year(i)==year(i+1))&&(month(i)~=month(i+1))
            monthd=timefunc(year(i));
            timetip(i)=(sec(i+1)-sec(i))+((day(i+1)+(monthd(month(i))-day(i)))*86400);
        elseif (year(i)~=year(i+1))
            monthd=timefunc(year(i));
            monthd1=timefunc(year(i+1));
            if month(i)~=12
                timetip(i)=(sec(i+1)-sec(i))+((day(i+1)+sum(monthd1(1:(month(i+1)-1)))+sum(monthd(month(i)+1):monthd(end))+(monthd(month(i))-day(i)))*86400);
            else
                timetip(i)=(sec(i+1)-sec(i))+((day(i+1)+sum(monthd1(1:(month(i+1)-1)))+(monthd(month(i))-day(i)))*86400);
            end
        end
    end

    timetipmin=timetip./60; 
    l=size(timetipmin);
   
    if k==1
            dtg=0;
        end
    for i = 1:length(timetipmin)
        
    %ensure there is no division by zero
        if (timetipmin(i)-tipmin(1)==0)
            wt1=1;
            wt2=0;
            wt3=0;
            wt4=0;
        else
             wt1=1/((timetipmin(i)-tipmin(1))^2);
        end
        if (timetipmin(i)-tipmin(2)==0)
            wt1=0;
            wt2=1;
            wt3=0;
            wt4=0;
        else
            wt2=1/((timetipmin(i)-tipmin(2))^2);
        end
        if (timetipmin(i)-tipmin(3)==0)
           wt1=0;
           wt2=0;
           wt3=1;
           wt4=0;
        else
           wt3=1/((timetipmin(i)-tipmin(3))^2);
        end
        if (timetipmin(i)-tipmin(4)==0)
            wt1=0;
            wt2=0;
            wt3=0;
            wt4=1;
        else
            wt4=1/((timetipmin(i)-tipmin(4))^2);
        end
        dtg=dtg+((wt1*dmm(1) + wt2*dmm(2) + wt3*dmm(3) + wt4*dmm(4))./(wt1+wt2+wt3+wt4))';
        y=[dtg/25.4 month(i) day(i) year(i) h(i) m(i) s(i)];
        fprintf(fid,'%10s %2d/%2d/%4d %3d:%2d:%6.3f\n',y);
    end
    
    %ensure that if you go through the loop a second time these two vectors
    %will be the correct size
    clear timetipmin timetip
end
fclose(fid);
cumulativeinches=dtg/25.4

